function [nothing] = ifa24cl(KP,One_TI,TD);

disp('Function ifa24cl(KP,1/TI,TD): PID controller design');
disp(' last change: 2009/09/22');
disp(' ');
Text =  [' KP: ' num2str(KP) ' [-]'];
disp(Text);
Text =  [' 1/TI: ' num2str(One_TI) ' sec^-1'];
disp(Text);
Text =  [' TD: ' num2str(TD) ' sec'];
disp(Text);

Text2 = [' KP: ' num2str(KP) ' [-]'];
Text3 = [' 1/TI: ' num2str(One_TI) ' sec^-1 '];
Text4 = [' TD: ' num2str(TD) ' sec'];
% =======================================================

% main motor
RA = 8.5;       % armature resistance [V/A]
LA = 1.3e-3;    % armature inductance [Vs/A]
KG = 52.5e-3;  	% generator constant [V/(rad/s)]
KM = 51.2e-3;  	% motor constant [Nm/A]

% tacho
KT = 45.82e-3;  	% tacho constant [V/(rad/s)]

% low-pass filter
OmegaF = 20;   	% cut-off frequency [rad/s]
DF2 = 1.414;   	% damping factor (maximally flat)

% steps
UFF = 5.0;      % feedforward step [V]
ML  = 10e-3;    % load moment step [Nm]
Uref = 5.0;     % reference value step [V] 
TF = 10;         % simulation duration [s]

% Rotor
Theta =125e-6;  % moment of inertia [kg/m^2]

% state space representation:
% x1 = IA, x2 = Omega , x3, x4 = UOmega, x5, x6
if TD == 0
    k = 0;
    T = 1;
else
    k = 10;
    T = 0.1*TD;
end

% =======================================================

A =[  -RA/LA     -KG/LA            0    -1/LA*(KP+k)   One_TI/LA        -k/LA
    KM/Theta          0            0              0            0            0
           0  KT*OmegaF  -DF2*OmegaF        -OmegaF            0            0
           0          0       OmegaF              0            0            0
           0          0            0             -1            0            0
           0          0            0            -1/T           0         -1/T];

B = [  1/LA*UFF           0     1/LA*(KP+k)*Uref
              0   -ML/Theta                    0
              0           0                    0
              0           0                    0
              0           0                 Uref
              0           0             1/T*Uref];

C = [0 0 0        1   0   0
     0 0 0 -KP-k  One_TI -k];
D = [  0  0       0
     UFF  0  (KP+k)*Uref];

% state space model
SYS = ss(A,B,C,D);

% step responses
t = 0 : 0.01 : TF;
y = step(SYS,t);  %y is matrix!

disp(' ');
disp(' Plot Figure 1');
figure(1);
subplot(321);
plot(t,y(:,1,3),'b');
title('system response U_{ref}-step');
grid on;
%xlabel('time [s]'); 
ylabel('\Delta U_{\omega} [V]');

subplot(323);
plot(t,y(:,1,2),'b')
title('system response M_L-step');
grid on;
%xlabel('time [s]'); 
ylabel('\Delta U_{\omega} [V]');

subplot(325);
plot(t,y(:,1,1),'b')
title('system response U_{FF}-step');
grid on;
xlabel('time [s]'); 
ylabel('\Delta U_{\omega} [V]');
%legend(Text2,1);

subplot(322);
plot(t,y(:,2,3)+3.1,'b')  % with U_FF = 3.1
title('U_{R} for U_{ref}-step');
grid on;
%xlabel('time [s]'); 
ylabel('U_R [V]');

subplot(324);
plot(t,y(:,2,2)+3.1,'b')   % with U_FF = 3.1
title('U_{R} for M_L-step');
grid on;
%xlabel('time [s]'); 
ylabel(' U_R [V]');

subplot(326);
plot(t,y(:,2,1)+3.1,'b')  % with U_FF = 3.1
title('U_R for U_{FF}-step');
grid on;
xlabel('time [s]'); ylabel(' U_R [V]');
%legend(Text2,1);

% disp(' saving postscript file ifa24cl.ps of Figure 1');
% orient tall;
% print -dps ifa24cl.ps 

disp('End Function ifa24cl(KP,1/TI,TD)');
