function [nothing] = ifa24ol;

disp('Function ifa24ol: step response of the plant (open loop)');
disp(' last changed: 2009/11/20');

% ===================================================

% main motor
RA = 8.5;       % armature resistance [V/A]
LA = 1.3e-3;    % armature inductance [Vs/A]
KG = 52.5e-3;  	% generator constant [V/(rad/s)]
KM = 51.2e-3;  	% motor constant [Nm/A]

% tacho
KT = 45.82e-3;  % tacho constant [V/(rad/s)]

% low-pass filter
OmegaF = 20;   	% cut-off frequency [rad/s]
DF2 = 1.414;   	% damping factor (maximally flat)

% steps
ML  = 6e-3;     % load moment step [Nm]
UR = 5;       % set value step [V] 
TF = 10;        % simulation duration [s]

% Rotor
Theta = 125e-6;  % moment of inertia [kg/m^2]

% state space representation:
% x1 = IA, x2 = Omega , x3, x4 = UOmega
% ===================================================

A = [   -RA/LA     -KG/LA           0          0
      KM/Theta          0           0          0
             0  KT*OmegaF -DF2*OmegaF    -OmegaF
             0          0      OmegaF          0];

B = [  1/LA*UR           0
             0   -ML/Theta 
             0           0 
             0           0];

C = [0 0 0 1];

D = [0 0];

% state space model
SYS = ss(A,B,C,D);

% step responses
t = 0 : 0.01 : TF;
y = step(SYS,t);  %y is matrix!

disp(' ');
disp(' Plot Figure 1');
figure(1);
subplot(311);
plot(t,y(:,1,1),'b');
title(['Plant: step response (U_R = ',num2str(UR),' V)']);
grid on;
xlabel('time [s]'); ylabel('\Delta U_{\omega} [V]');

subplot(312);
plot(t(2:end)-0.005,100*diff(y(:,1,1)),'r');
title(['Plant: d/dt of the step response (U_R = ',num2str(UR),' V)']);
grid on;
xlabel('time [s]');

subplot(313);
plot(t,y(:,1,2),'b')
title(['Plant: load moment step (M_L = ',num2str(1000*ML),' mNm)']);
grid on;
xlabel('time [s]'); ylabel('\Delta U_{\omega} [V]');


% disp(' saving postscript file ifa24ol.ps of Figure 1');
% orient tall;
% print -dps ifa24ol.ps

disp('End Function ifa24ol');
